favorites=exo-terminal-emulator.desktop,exo-web-browser.desktop,wps-office-wps.desktop,wps-office-et.desktop,wps-office-wpp.desktop,org.gnome.Evince.desktop,gimp.desktop,exo-file-manager.desktop,org.gnome.Calculator.desktop
recent=wps-office-wps.desktop,libreoffice-writer.desktop,exo-terminal-emulator.desktop,chromium.desktop,org.gnome.seahorse.Application.desktop,exo-file-manager.desktop,htop.desktop,mousepad.desktop,realvnc-vncserver-service.desktop,org.remmina.Remmina.desktop
button-icon=/usr/share/icons/ub_b.svg
button-single-row=false
show-button-title=false
show-button-icon=true
launcher-show-name=true
launcher-show-description=true
launcher-show-tooltip=true
item-icon-size=2
hover-switch-category=false
category-show-name=true
category-icon-size=2
load-hierarchy=false
view-as-icons=false
default-category=0
recent-items-max=10
favorites-in-recent=true
display-recent-default=false
position-search-alternate=true
position-commands-alternate=true
position-categories-alternate=true
stay-on-focus-out=false
confirm-session-command=true
menu-width=707
menu-height=644
menu-opacity=90
command-settings=xfce4-settings-manager
show-command-settings=true
command-lockscreen=dm-tool lock
show-command-lockscreen=true
command-switchuser=dm-tool switch-to-greeter
show-command-switchuser=false
command-logoutuser=xfce4-session-logout --logout --fast
show-command-logoutuser=false
command-restart=xfce4-session-logout --reboot --fast
show-command-restart=false
command-shutdown=xfce4-session-logout --halt --fast
show-command-shutdown=false
command-suspend=xfce4-session-logout --suspend
show-command-suspend=false
command-hibernate=xfce4-session-logout --hibernate
show-command-hibernate=false
command-logout=xfce4-session-logout
show-command-logout=true
command-menueditor=menulibre
show-command-menueditor=true
command-profile=mugshot
show-command-profile=true
search-actions=5

[action0]
name=Man-страницы
pattern=#
command=exo-open --launch TerminalEmulator man %s
regex=false

[action1]
name=Поиск в Веб
pattern=?
command=exo-open --launch WebBrowser https://duckduckgo.com/?q=%u
regex=false

[action2]
name=Википедия
pattern=!w
command=exo-open --launch WebBrowser https://en.wikipedia.org/wiki/%u
regex=false

[action3]
name=Выполнить в терминале
pattern=!
command=exo-open --launch TerminalEmulator %s
regex=false

[action4]
name=Открыть URI
pattern=^(file|http|https):\\/\\/(.*)$
command=exo-open \\0
regex=true

